// Copyright (c) Microsoft Corporation
// All rights reserved. 
//
// Licensed under the Apache License, Version 2.0 (the ""License""); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED ON AN  *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT. 
//
// See the Apache Version 2.0 License for specific language governing permissions and limitations under the License.

#define NTDDI_VERSION 0x06010000

#include <v8.h>
#include <string>
#include <node_object_wrap.h>
#include <ppltasks.h>
#include "CollectionsConverter.h"
#include "CollectionsWrap.h"
#include "node-async.h"
#include "NodeRtUtils.h"
#include "OpaqueWrapper.h"
#include "WrapperBase.h"

#using <Windows.WinMD>

// this undefs fixes the issues of compiling Windows.Data.Json, Windows.Storag.FileProperties, and Windows.Stroage.Search
// Some of the node header files brings windows definitions with the same names as some of the WinRT methods
#undef DocumentProperties
#undef GetObject
#undef CreateEvent
#undef FindText
#undef SendMessage

const char* REGISTRATION_TOKEN_MAP_PROPERTY_NAME = "__registrationTokenMap__";

using namespace v8;
using namespace node;
using namespace concurrency;

namespace NodeRT { namespace Windows { namespace Data { namespace Xml { namespace Dom { 
  v8::Handle<v8::Value> WrapIXmlNodeSelector(::Windows::Data::Xml::Dom::IXmlNodeSelector^ wintRtInstance);
  ::Windows::Data::Xml::Dom::IXmlNodeSelector^ UnwrapIXmlNodeSelector(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlNodeList(::Windows::Data::Xml::Dom::XmlNodeList^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlNodeList^ UnwrapXmlNodeList(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlNamedNodeMap(::Windows::Data::Xml::Dom::XmlNamedNodeMap^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ UnwrapXmlNamedNodeMap(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlDocument(::Windows::Data::Xml::Dom::XmlDocument^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlDocument^ UnwrapXmlDocument(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIXmlNodeSerializer(::Windows::Data::Xml::Dom::IXmlNodeSerializer^ wintRtInstance);
  ::Windows::Data::Xml::Dom::IXmlNodeSerializer^ UnwrapIXmlNodeSerializer(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIXmlNode(::Windows::Data::Xml::Dom::IXmlNode^ wintRtInstance);
  ::Windows::Data::Xml::Dom::IXmlNode^ UnwrapIXmlNode(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlAttribute(::Windows::Data::Xml::Dom::XmlAttribute^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlAttribute^ UnwrapXmlAttribute(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIXmlCharacterData(::Windows::Data::Xml::Dom::IXmlCharacterData^ wintRtInstance);
  ::Windows::Data::Xml::Dom::IXmlCharacterData^ UnwrapIXmlCharacterData(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapIXmlText(::Windows::Data::Xml::Dom::IXmlText^ wintRtInstance);
  ::Windows::Data::Xml::Dom::IXmlText^ UnwrapIXmlText(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlDocumentType(::Windows::Data::Xml::Dom::XmlDocumentType^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlDocumentType^ UnwrapXmlDocumentType(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlDomImplementation(::Windows::Data::Xml::Dom::XmlDomImplementation^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlDomImplementation^ UnwrapXmlDomImplementation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlElement(::Windows::Data::Xml::Dom::XmlElement^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlElement^ UnwrapXmlElement(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlDocumentFragment(::Windows::Data::Xml::Dom::XmlDocumentFragment^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlDocumentFragment^ UnwrapXmlDocumentFragment(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlText(::Windows::Data::Xml::Dom::XmlText^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlText^ UnwrapXmlText(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlComment(::Windows::Data::Xml::Dom::XmlComment^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlComment^ UnwrapXmlComment(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlProcessingInstruction(::Windows::Data::Xml::Dom::XmlProcessingInstruction^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ UnwrapXmlProcessingInstruction(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlEntityReference(::Windows::Data::Xml::Dom::XmlEntityReference^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlEntityReference^ UnwrapXmlEntityReference(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlCDataSection(::Windows::Data::Xml::Dom::XmlCDataSection^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlCDataSection^ UnwrapXmlCDataSection(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapXmlLoadSettings(::Windows::Data::Xml::Dom::XmlLoadSettings^ wintRtInstance);
  ::Windows::Data::Xml::Dom::XmlLoadSettings^ UnwrapXmlLoadSettings(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapDtdNotation(::Windows::Data::Xml::Dom::DtdNotation^ wintRtInstance);
  ::Windows::Data::Xml::Dom::DtdNotation^ UnwrapDtdNotation(Handle<Value> value);
  
  v8::Handle<v8::Value> WrapDtdEntity(::Windows::Data::Xml::Dom::DtdEntity^ wintRtInstance);
  ::Windows::Data::Xml::Dom::DtdEntity^ UnwrapDtdEntity(Handle<Value> value);
  


  static v8::Handle<v8::Value> InitNodeTypeEnum(const Handle<Object> exports)
  {
    HandleScope scope;
    
    Handle<Object> enumObject = Object::New();
    exports->Set(String::NewSymbol("NodeType"), enumObject);

    enumObject->Set(String::NewSymbol("invalid"), Integer::New(0));
    enumObject->Set(String::NewSymbol("elementNode"), Integer::New(1));
    enumObject->Set(String::NewSymbol("attributeNode"), Integer::New(2));
    enumObject->Set(String::NewSymbol("textNode"), Integer::New(3));
    enumObject->Set(String::NewSymbol("dataSectionNode"), Integer::New(4));
    enumObject->Set(String::NewSymbol("entityReferenceNode"), Integer::New(5));
    enumObject->Set(String::NewSymbol("entityNode"), Integer::New(6));
    enumObject->Set(String::NewSymbol("processingInstructionNode"), Integer::New(7));
    enumObject->Set(String::NewSymbol("commentNode"), Integer::New(8));
    enumObject->Set(String::NewSymbol("documentNode"), Integer::New(9));
    enumObject->Set(String::NewSymbol("documentTypeNode"), Integer::New(10));
    enumObject->Set(String::NewSymbol("documentFragmentNode"), Integer::New(11));
    enumObject->Set(String::NewSymbol("notationNode"), Integer::New(12));

    return scope.Close(Undefined());
  }



  
  class IXmlNodeSelector : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IXmlNodeSelector"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IXmlNodeSelector"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IXmlNodeSelector(::Windows::Data::Xml::Dom::IXmlNodeSelector^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::IXmlNodeSelector^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSelector^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::IXmlNodeSelector^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IXmlNodeSelector *wrapperInstance = new IXmlNodeSelector(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSelector^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSelector *wrapper = IXmlNodeSelector::Unwrap<IXmlNodeSelector>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSelector^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSelector *wrapper = IXmlNodeSelector::Unwrap<IXmlNodeSelector>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSelector^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSelector *wrapper = IXmlNodeSelector::Unwrap<IXmlNodeSelector>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSelector^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSelector *wrapper = IXmlNodeSelector::Unwrap<IXmlNodeSelector>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Data::Xml::Dom::IXmlNodeSelector^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIXmlNodeSelector(::Windows::Data::Xml::Dom::IXmlNodeSelector^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::IXmlNodeSelector^ UnwrapIXmlNodeSelector(Handle<Value> value);
    friend bool IsIXmlNodeSelectorWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IXmlNodeSelector::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIXmlNodeSelector(::Windows::Data::Xml::Dom::IXmlNodeSelector^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IXmlNodeSelector::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::IXmlNodeSelector^ UnwrapIXmlNodeSelector(Handle<Value> value)
  {
     return IXmlNodeSelector::Unwrap<IXmlNodeSelector>(value.As<Object>())->_instance;
  }

  void InitIXmlNodeSelector(Handle<Object> exports)
  {
    IXmlNodeSelector::Init(exports);
  }

  class XmlNodeList : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlNodeList"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("item"), FunctionTemplate::New(Item)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAt"), FunctionTemplate::New(GetAt)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("indexOf"), FunctionTemplate::New(IndexOf)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getMany"), FunctionTemplate::New(GetMany)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("first"), FunctionTemplate::New(First)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlNodeList"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlNodeList(::Windows::Data::Xml::Dom::XmlNodeList^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlNodeList^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlNodeList^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlNodeList *wrapperInstance = new XmlNodeList(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> Item(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->Item(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetAt(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->GetAt(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> IndexOf(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          unsigned int arg1;
          
          bool result;
          result = wrapper->_instance->IndexOf(arg0, &arg1);
          Handle<Object> resObj = Object::New();
          resObj->Set(String::NewSymbol("boolean"), Boolean::New(result));
          resObj->Set(String::NewSymbol("index"), Integer::New(arg1));
          return scope.Close(resObj);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetMany(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          ::Platform::Array<::Windows::Data::Xml::Dom::IXmlNode^>^ arg1 = ref new ::Platform::Array<::Windows::Data::Xml::Dom::IXmlNode^>(wrapper->_instance->Length - arg0);
          
          unsigned int result;
          result = wrapper->_instance->GetMany(arg0, arg1);
          Handle<Object> resObj = Object::New();
          resObj->Set(String::NewSymbol("number"), Integer::New(result));
          resObj->Set(String::NewSymbol("items"), NodeRT::Collections::ArrayWrapper<::Windows::Data::Xml::Dom::IXmlNode^>::CreateArrayWrapper(arg1, 
            [](::Windows::Data::Xml::Dom::IXmlNode^ val) -> Handle<Value> {
              return WrapIXmlNode(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Data::Xml::Dom::IXmlNode^ {
              return UnwrapIXmlNode(value);
            }
          ));
          return scope.Close(resObj);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> First(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Foundation::Collections::IIterator<::Windows::Data::Xml::Dom::IXmlNode^>^ result;
          result = wrapper->_instance->First();
          return scope.Close(NodeRT::Collections::IteratorWrapper<::Windows::Data::Xml::Dom::IXmlNode^>::CreateIteratorWrapper(result, 
            [](::Windows::Data::Xml::Dom::IXmlNode^ val) -> Handle<Value> {
              return WrapIXmlNode(val);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNodeList^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNodeList *wrapper = XmlNodeList::Unwrap<XmlNodeList>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlNodeList^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlNodeList(::Windows::Data::Xml::Dom::XmlNodeList^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlNodeList^ UnwrapXmlNodeList(Handle<Value> value);
    friend bool IsXmlNodeListWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlNodeList::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlNodeList(::Windows::Data::Xml::Dom::XmlNodeList^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlNodeList::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlNodeList^ UnwrapXmlNodeList(Handle<Value> value)
  {
     return XmlNodeList::Unwrap<XmlNodeList>(value.As<Object>())->_instance;
  }

  void InitXmlNodeList(Handle<Object> exports)
  {
    XmlNodeList::Init(exports);
  }

  class XmlNamedNodeMap : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlNamedNodeMap"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("item"), FunctionTemplate::New(Item)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getNamedItem"), FunctionTemplate::New(GetNamedItem)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setNamedItem"), FunctionTemplate::New(SetNamedItem)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeNamedItem"), FunctionTemplate::New(RemoveNamedItem)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getNamedItemNS"), FunctionTemplate::New(GetNamedItemNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeNamedItemNS"), FunctionTemplate::New(RemoveNamedItemNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setNamedItemNS"), FunctionTemplate::New(SetNamedItemNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAt"), FunctionTemplate::New(GetAt)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("indexOf"), FunctionTemplate::New(IndexOf)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getMany"), FunctionTemplate::New(GetMany)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("first"), FunctionTemplate::New(First)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlNamedNodeMap"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlNamedNodeMap(::Windows::Data::Xml::Dom::XmlNamedNodeMap^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlNamedNodeMap^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlNamedNodeMap *wrapperInstance = new XmlNamedNodeMap(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> Item(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->Item(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetNamedItem(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->GetNamedItem(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetNamedItem(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SetNamedItem(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveNamedItem(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveNamedItem(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetNamedItemNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->GetNamedItemNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveNamedItemNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveNamedItemNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetNamedItemNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SetNamedItemNS(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetAt(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->GetAt(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> IndexOf(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          unsigned int arg1;
          
          bool result;
          result = wrapper->_instance->IndexOf(arg0, &arg1);
          Handle<Object> resObj = Object::New();
          resObj->Set(String::NewSymbol("boolean"), Boolean::New(result));
          resObj->Set(String::NewSymbol("index"), Integer::New(arg1));
          return scope.Close(resObj);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetMany(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          ::Platform::Array<::Windows::Data::Xml::Dom::IXmlNode^>^ arg1 = ref new ::Platform::Array<::Windows::Data::Xml::Dom::IXmlNode^>(wrapper->_instance->Length - arg0);
          
          unsigned int result;
          result = wrapper->_instance->GetMany(arg0, arg1);
          Handle<Object> resObj = Object::New();
          resObj->Set(String::NewSymbol("number"), Integer::New(result));
          resObj->Set(String::NewSymbol("items"), NodeRT::Collections::ArrayWrapper<::Windows::Data::Xml::Dom::IXmlNode^>::CreateArrayWrapper(arg1, 
            [](::Windows::Data::Xml::Dom::IXmlNode^ val) -> Handle<Value> {
              return WrapIXmlNode(val);
            },
            [](Handle<Value> value) -> bool {
              return NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(value);
            },
            [](Handle<Value> value) -> ::Windows::Data::Xml::Dom::IXmlNode^ {
              return UnwrapIXmlNode(value);
            }
          ));
          return scope.Close(resObj);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> First(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Foundation::Collections::IIterator<::Windows::Data::Xml::Dom::IXmlNode^>^ result;
          result = wrapper->_instance->First();
          return scope.Close(NodeRT::Collections::IteratorWrapper<::Windows::Data::Xml::Dom::IXmlNode^>::CreateIteratorWrapper(result, 
            [](::Windows::Data::Xml::Dom::IXmlNode^ val) -> Handle<Value> {
              return WrapIXmlNode(val);
            }
          ));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlNamedNodeMap^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlNamedNodeMap *wrapper = XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlNamedNodeMap(::Windows::Data::Xml::Dom::XmlNamedNodeMap^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ UnwrapXmlNamedNodeMap(Handle<Value> value);
    friend bool IsXmlNamedNodeMapWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlNamedNodeMap::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlNamedNodeMap(::Windows::Data::Xml::Dom::XmlNamedNodeMap^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlNamedNodeMap::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ UnwrapXmlNamedNodeMap(Handle<Value> value)
  {
     return XmlNamedNodeMap::Unwrap<XmlNamedNodeMap>(value.As<Object>())->_instance;
  }

  void InitXmlNamedNodeMap(Handle<Object> exports)
  {
    XmlNamedNodeMap::Init(exports);
  }

  class XmlDocument : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlDocument"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
      Handle<Value> asyncSymbol = String::NewSymbol("__winRtAsync__");
      Handle<Function> func;
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createElement"), FunctionTemplate::New(CreateElement)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createDocumentFragment"), FunctionTemplate::New(CreateDocumentFragment)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createTextNode"), FunctionTemplate::New(CreateTextNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createComment"), FunctionTemplate::New(CreateComment)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createProcessingInstruction"), FunctionTemplate::New(CreateProcessingInstruction)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createAttribute"), FunctionTemplate::New(CreateAttribute)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createEntityReference"), FunctionTemplate::New(CreateEntityReference)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getElementsByTagName"), FunctionTemplate::New(GetElementsByTagName)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createCDataSection"), FunctionTemplate::New(CreateCDataSection)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createAttributeNS"), FunctionTemplate::New(CreateAttributeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("createElementNS"), FunctionTemplate::New(CreateElementNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getElementById"), FunctionTemplate::New(GetElementById)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("importNode"), FunctionTemplate::New(ImportNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("loadXml"), FunctionTemplate::New(LoadXml)->GetFunction());
      
            
      func = FunctionTemplate::New(SaveToFileAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("saveToFileAsync"), func);
      
                  
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("doctype"), DoctypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("documentElement"), DocumentElementGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("documentUri"), DocumentUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("implementation"), ImplementationGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();

      func = FunctionTemplate::New(LoadFromUriAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("loadFromUriAsync"), func);
      func = FunctionTemplate::New(LoadFromFileAsync)->GetFunction();
      func->Set(asyncSymbol, True(), PropertyAttribute::DontEnum);
      constructor->Set(String::NewSymbol("loadFromFileAsync"), func);

      exports->Set(String::NewSymbol("XmlDocument"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlDocument(::Windows::Data::Xml::Dom::XmlDocument^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlDocument^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlDocument^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Data::Xml::Dom::XmlDocument();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlDocument *wrapperInstance = new XmlDocument(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


    static Handle<Value> SaveToFileAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      ::Windows::Foundation::IAsyncAction^ op;
    

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[0]))
      {
        try
        {
          ::Windows::Storage::IStorageFile^ arg0 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[0]));
          
          op = wrapper->_instance->SaveToFileAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<void> t) 
      {	
        try
        {
          t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [](NodeUtils::InvokeCallbackDelegate invokeCallback) {


            Handle<Value> args[] = {Undefined()};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
             
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
  
    static Handle<Value> CreateElement(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlElement^ result;
          result = wrapper->_instance->CreateElement(arg0);
          return scope.Close(WrapXmlElement(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateDocumentFragment(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          ::Windows::Data::Xml::Dom::XmlDocumentFragment^ result;
          result = wrapper->_instance->CreateDocumentFragment();
          return scope.Close(WrapXmlDocumentFragment(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateTextNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlText^ result;
          result = wrapper->_instance->CreateTextNode(arg0);
          return scope.Close(WrapXmlText(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateComment(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlComment^ result;
          result = wrapper->_instance->CreateComment(arg0);
          return scope.Close(WrapXmlComment(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateProcessingInstruction(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ result;
          result = wrapper->_instance->CreateProcessingInstruction(arg0, arg1);
          return scope.Close(WrapXmlProcessingInstruction(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateAttribute(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->CreateAttribute(arg0);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateEntityReference(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlEntityReference^ result;
          result = wrapper->_instance->CreateEntityReference(arg0);
          return scope.Close(WrapXmlEntityReference(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetElementsByTagName(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->GetElementsByTagName(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateCDataSection(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlCDataSection^ result;
          result = wrapper->_instance->CreateCDataSection(arg0);
          return scope.Close(WrapXmlCDataSection(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateAttributeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->CreateAttributeNS(arg0, arg1);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CreateElementNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::XmlElement^ result;
          result = wrapper->_instance->CreateElementNS(arg0, arg1);
          return scope.Close(WrapXmlElement(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetElementById(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlElement^ result;
          result = wrapper->_instance->GetElementById(arg0);
          return scope.Close(WrapXmlElement(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ImportNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && args[1]->IsBoolean())
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          bool arg1 = args[1]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ImportNode(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> LoadXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->LoadXml(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Windows::Data::Xml::Dom::XmlLoadSettings^ arg1 = UnwrapXmlLoadSettings(args[1]);
          
          wrapper->_instance->LoadXml(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }

    static Handle<Value> LoadFromUriAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Data::Xml::Dom::XmlDocument^>^ op;
      

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          
          op = ::Windows::Data::Xml::Dom::XmlDocument::LoadFromUriAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Foundation::Uri^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(args[1]))
      {
        try
        {
          ::Windows::Foundation::Uri^ arg0 = dynamic_cast<::Windows::Foundation::Uri^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Data::Xml::Dom::XmlLoadSettings^ arg1 = UnwrapXmlLoadSettings(args[1]);
          
          op = ::Windows::Data::Xml::Dom::XmlDocument::LoadFromUriAsync(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Data::Xml::Dom::XmlDocument^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapXmlDocument(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }
    static Handle<Value> LoadFromFileAsync(const v8::Arguments& args)
    {
      HandleScope scope;

      if (args.Length() == 0 || !args[args.Length() -1]->IsFunction())
      {
          ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: No callback was given")));
          return scope.Close(Undefined());
      }

      ::Windows::Foundation::IAsyncOperation<::Windows::Data::Xml::Dom::XmlDocument^>^ op;
      

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[0]))
      {
        try
        {
          ::Windows::Storage::IStorageFile^ arg0 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[0]));
          
          op = ::Windows::Data::Xml::Dom::XmlDocument::LoadFromFileAsync(arg0);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Storage::IStorageFile^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(args[1]))
      {
        try
        {
          ::Windows::Storage::IStorageFile^ arg0 = dynamic_cast<::Windows::Storage::IStorageFile^>(NodeRT::Utils::GetObjectInstance(args[0]));
          ::Windows::Data::Xml::Dom::XmlLoadSettings^ arg1 = UnwrapXmlLoadSettings(args[1]);
          
          op = ::Windows::Data::Xml::Dom::XmlDocument::LoadFromFileAsync(arg0,arg1);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }
    
      auto opTask = create_task(op);
      uv_async_t* asyncToken = NodeUtils::Async::GetAsyncToken(args[args.Length() -1].As<Function>());

      opTask.then( [asyncToken] (task<::Windows::Data::Xml::Dom::XmlDocument^> t) 
      {	
        try
        {
          auto result = t.get();
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [result](NodeUtils::InvokeCallbackDelegate invokeCallback) {

            
            TryCatch tryCatch;
            Handle<Value> error; 
            Handle<Value> arg1 = WrapXmlDocument(result);
            if (tryCatch.HasCaught())
            {
              error = tryCatch.Exception()->ToObject();
            }
            else 
            {
              error = Undefined();
            }
            if (arg1.IsEmpty()) arg1 = Undefined();
            Handle<Value> args[] = {error, arg1};

            invokeCallback(_countof(args), args);
          });
        }
        catch (Platform::Exception^ exception)
        {
          NodeUtils::Async::RunCallbackOnMain(asyncToken, [exception](NodeUtils::InvokeCallbackDelegate invokeCallback) {
          
            Handle<Value> error = NodeRT::Utils::WinRtExceptionToJsError(exception);
        
            Handle<Value> args[] = {error};
            invokeCallback(_countof(args), args);
          });
        }  		
      });

      return scope.Close(Undefined());
    }


    static Handle<Value> DoctypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocumentType^ result = wrapper->_instance->Doctype;
        return scope.Close(WrapXmlDocumentType(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DocumentElementGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlElement^ result = wrapper->_instance->DocumentElement;
        return scope.Close(WrapXmlElement(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> DocumentUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->DocumentUri;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ImplementationGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDomImplementation^ result = wrapper->_instance->Implementation;
        return scope.Close(WrapXmlDomImplementation(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return;
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return;
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocument^>(info.This()))
      {
        return;
      }

      XmlDocument *wrapper = XmlDocument::Unwrap<XmlDocument>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlDocument^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlDocument(::Windows::Data::Xml::Dom::XmlDocument^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlDocument^ UnwrapXmlDocument(Handle<Value> value);
    friend bool IsXmlDocumentWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlDocument::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlDocument(::Windows::Data::Xml::Dom::XmlDocument^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlDocument::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlDocument^ UnwrapXmlDocument(Handle<Value> value)
  {
     return XmlDocument::Unwrap<XmlDocument>(value.As<Object>())->_instance;
  }

  void InitXmlDocument(Handle<Object> exports)
  {
    XmlDocument::Init(exports);
  }

  class IXmlNodeSerializer : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IXmlNodeSerializer"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IXmlNodeSerializer"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IXmlNodeSerializer(::Windows::Data::Xml::Dom::IXmlNodeSerializer^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::IXmlNodeSerializer^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSerializer^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::IXmlNodeSerializer^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IXmlNodeSerializer *wrapperInstance = new IXmlNodeSerializer(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSerializer^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSerializer *wrapper = IXmlNodeSerializer::Unwrap<IXmlNodeSerializer>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSerializer^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNodeSerializer *wrapper = IXmlNodeSerializer::Unwrap<IXmlNodeSerializer>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNodeSerializer^>(info.This()))
      {
        return;
      }

      IXmlNodeSerializer *wrapper = IXmlNodeSerializer::Unwrap<IXmlNodeSerializer>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::IXmlNodeSerializer^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIXmlNodeSerializer(::Windows::Data::Xml::Dom::IXmlNodeSerializer^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::IXmlNodeSerializer^ UnwrapIXmlNodeSerializer(Handle<Value> value);
    friend bool IsIXmlNodeSerializerWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IXmlNodeSerializer::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIXmlNodeSerializer(::Windows::Data::Xml::Dom::IXmlNodeSerializer^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IXmlNodeSerializer::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::IXmlNodeSerializer^ UnwrapIXmlNodeSerializer(Handle<Value> value)
  {
     return IXmlNodeSerializer::Unwrap<IXmlNodeSerializer>(value.As<Object>())->_instance;
  }

  void InitIXmlNodeSerializer(Handle<Object> exports)
  {
    IXmlNodeSerializer::Init(exports);
  }

  class IXmlNode : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IXmlNode"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IXmlNode"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IXmlNode(::Windows::Data::Xml::Dom::IXmlNode^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::IXmlNode^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::IXmlNode^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IXmlNode *wrapperInstance = new IXmlNode(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return;
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return;
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlNode *wrapper = IXmlNode::Unwrap<IXmlNode>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::IXmlNode^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIXmlNode(::Windows::Data::Xml::Dom::IXmlNode^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::IXmlNode^ UnwrapIXmlNode(Handle<Value> value);
    friend bool IsIXmlNodeWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IXmlNode::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIXmlNode(::Windows::Data::Xml::Dom::IXmlNode^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IXmlNode::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::IXmlNode^ UnwrapIXmlNode(Handle<Value> value)
  {
     return IXmlNode::Unwrap<IXmlNode>(value.As<Object>())->_instance;
  }

  void InitIXmlNode(Handle<Object> exports)
  {
    IXmlNode::Init(exports);
  }

  class XmlAttribute : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlAttribute"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("value"), ValueGetter, ValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("specified"), SpecifiedGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlAttribute"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlAttribute(::Windows::Data::Xml::Dom::XmlAttribute^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlAttribute^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlAttribute^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlAttribute *wrapperInstance = new XmlAttribute(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> ValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Value;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return;
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Value = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SpecifiedGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        bool result = wrapper->_instance->Specified;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return;
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return;
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(info.This()))
      {
        return;
      }

      XmlAttribute *wrapper = XmlAttribute::Unwrap<XmlAttribute>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlAttribute^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlAttribute(::Windows::Data::Xml::Dom::XmlAttribute^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlAttribute^ UnwrapXmlAttribute(Handle<Value> value);
    friend bool IsXmlAttributeWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlAttribute::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlAttribute(::Windows::Data::Xml::Dom::XmlAttribute^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlAttribute::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlAttribute^ UnwrapXmlAttribute(Handle<Value> value)
  {
     return XmlAttribute::Unwrap<XmlAttribute>(value.As<Object>())->_instance;
  }

  void InitXmlAttribute(Handle<Object> exports)
  {
    XmlAttribute::Init(exports);
  }

  class IXmlCharacterData : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IXmlCharacterData"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("substringData"), FunctionTemplate::New(SubstringData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendData"), FunctionTemplate::New(AppendData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertData"), FunctionTemplate::New(InsertData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteData"), FunctionTemplate::New(DeleteData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceData"), FunctionTemplate::New(ReplaceData)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("data"), DataGetter, DataSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IXmlCharacterData"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IXmlCharacterData(::Windows::Data::Xml::Dom::IXmlCharacterData^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::IXmlCharacterData^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::IXmlCharacterData^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IXmlCharacterData *wrapperInstance = new IXmlCharacterData(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SubstringData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          Platform::String^ result;
          result = wrapper->_instance->SubstringData(arg0, arg1);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->AppendData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->InsertData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> DeleteData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          wrapper->_instance->DeleteData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(args.This());

      if (args.Length() == 3
        && args[0]->IsUint32()
        && args[1]->IsUint32()
        && args[2]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          wrapper->_instance->ReplaceData(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> DataGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Data;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(info.This()))
      {
        return;
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Data = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlCharacterData^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlCharacterData *wrapper = IXmlCharacterData::Unwrap<IXmlCharacterData>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::IXmlCharacterData^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIXmlCharacterData(::Windows::Data::Xml::Dom::IXmlCharacterData^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::IXmlCharacterData^ UnwrapIXmlCharacterData(Handle<Value> value);
    friend bool IsIXmlCharacterDataWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IXmlCharacterData::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIXmlCharacterData(::Windows::Data::Xml::Dom::IXmlCharacterData^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IXmlCharacterData::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::IXmlCharacterData^ UnwrapIXmlCharacterData(Handle<Value> value)
  {
     return IXmlCharacterData::Unwrap<IXmlCharacterData>(value.As<Object>())->_instance;
  }

  void InitIXmlCharacterData(Handle<Object> exports)
  {
    IXmlCharacterData::Init(exports);
  }

  class IXmlText : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("IXmlText"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("splitText"), FunctionTemplate::New(SplitText)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("IXmlText"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    IXmlText(::Windows::Data::Xml::Dom::IXmlText^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::IXmlText^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlText^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::IXmlText^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      IXmlText *wrapperInstance = new IXmlText(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SplitText(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      IXmlText *wrapper = IXmlText::Unwrap<IXmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlText^ result;
          result = wrapper->_instance->SplitText(arg0);
          return scope.Close(WrapIXmlText(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Data::Xml::Dom::IXmlText^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapIXmlText(::Windows::Data::Xml::Dom::IXmlText^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::IXmlText^ UnwrapIXmlText(Handle<Value> value);
    friend bool IsIXmlTextWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> IXmlText::s_constructorTemplate;

  v8::Handle<v8::Value> WrapIXmlText(::Windows::Data::Xml::Dom::IXmlText^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(IXmlText::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::IXmlText^ UnwrapIXmlText(Handle<Value> value)
  {
     return IXmlText::Unwrap<IXmlText>(value.As<Object>())->_instance;
  }

  void InitIXmlText(Handle<Object> exports)
  {
    IXmlText::Init(exports);
  }

  class XmlDocumentType : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlDocumentType"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("entities"), EntitiesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("name"), NameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("notations"), NotationsGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlDocumentType"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlDocumentType(::Windows::Data::Xml::Dom::XmlDocumentType^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlDocumentType^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlDocumentType^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlDocumentType *wrapperInstance = new XmlDocumentType(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> EntitiesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Entities;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Name;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NotationsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Notations;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return;
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return;
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentType^>(info.This()))
      {
        return;
      }

      XmlDocumentType *wrapper = XmlDocumentType::Unwrap<XmlDocumentType>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlDocumentType^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlDocumentType(::Windows::Data::Xml::Dom::XmlDocumentType^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlDocumentType^ UnwrapXmlDocumentType(Handle<Value> value);
    friend bool IsXmlDocumentTypeWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlDocumentType::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlDocumentType(::Windows::Data::Xml::Dom::XmlDocumentType^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlDocumentType::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlDocumentType^ UnwrapXmlDocumentType(Handle<Value> value)
  {
     return XmlDocumentType::Unwrap<XmlDocumentType>(value.As<Object>())->_instance;
  }

  void InitXmlDocumentType(Handle<Object> exports)
  {
    XmlDocumentType::Init(exports);
  }

  class XmlDomImplementation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlDomImplementation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasFeature"), FunctionTemplate::New(HasFeature)->GetFunction());
      
                        
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlDomImplementation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlDomImplementation(::Windows::Data::Xml::Dom::XmlDomImplementation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlDomImplementation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDomImplementation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlDomImplementation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlDomImplementation *wrapperInstance = new XmlDomImplementation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasFeature(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDomImplementation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDomImplementation *wrapper = XmlDomImplementation::Unwrap<XmlDomImplementation>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          bool result;
          result = wrapper->_instance->HasFeature(arg0, arg1);
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }





  private:
    ::Windows::Data::Xml::Dom::XmlDomImplementation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlDomImplementation(::Windows::Data::Xml::Dom::XmlDomImplementation^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlDomImplementation^ UnwrapXmlDomImplementation(Handle<Value> value);
    friend bool IsXmlDomImplementationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlDomImplementation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlDomImplementation(::Windows::Data::Xml::Dom::XmlDomImplementation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlDomImplementation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlDomImplementation^ UnwrapXmlDomImplementation(Handle<Value> value)
  {
     return XmlDomImplementation::Unwrap<XmlDomImplementation>(value.As<Object>())->_instance;
  }

  void InitXmlDomImplementation(Handle<Object> exports)
  {
    XmlDomImplementation::Init(exports);
  }

  class XmlElement : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlElement"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAttribute"), FunctionTemplate::New(GetAttribute)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setAttribute"), FunctionTemplate::New(SetAttribute)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeAttribute"), FunctionTemplate::New(RemoveAttribute)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAttributeNode"), FunctionTemplate::New(GetAttributeNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setAttributeNode"), FunctionTemplate::New(SetAttributeNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeAttributeNode"), FunctionTemplate::New(RemoveAttributeNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getElementsByTagName"), FunctionTemplate::New(GetElementsByTagName)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setAttributeNS"), FunctionTemplate::New(SetAttributeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAttributeNS"), FunctionTemplate::New(GetAttributeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeAttributeNS"), FunctionTemplate::New(RemoveAttributeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("setAttributeNodeNS"), FunctionTemplate::New(SetAttributeNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getAttributeNodeNS"), FunctionTemplate::New(GetAttributeNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("tagName"), TagNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlElement"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlElement(::Windows::Data::Xml::Dom::XmlElement^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlElement^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlElement^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlElement *wrapperInstance = new XmlElement(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> GetAttribute(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          Platform::String^ result;
          result = wrapper->_instance->GetAttribute(arg0);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetAttribute(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && args[1]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->SetAttribute(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveAttribute(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->RemoveAttribute(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetAttributeNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->GetAttributeNode(arg0);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetAttributeNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::XmlAttribute^ arg0 = UnwrapXmlAttribute(args[0]);
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->SetAttributeNode(arg0);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveAttributeNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::XmlAttribute^ arg0 = UnwrapXmlAttribute(args[0]);
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->RemoveAttributeNode(arg0);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetElementsByTagName(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->GetElementsByTagName(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetAttributeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 3
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString()
        && args[2]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          wrapper->_instance->SetAttributeNS(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetAttributeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          Platform::String^ result;
          result = wrapper->_instance->GetAttributeNS(arg0, arg1);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveAttributeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->RemoveAttributeNS(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SetAttributeNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlAttribute^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::XmlAttribute^ arg0 = UnwrapXmlAttribute(args[0]);
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->SetAttributeNodeNS(arg0);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetAttributeNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[0])
        && args[1]->IsString())
      {
        try
        {
          ::Platform::Object^ arg0 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[0]));
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          ::Windows::Data::Xml::Dom::XmlAttribute^ result;
          result = wrapper->_instance->GetAttributeNodeNS(arg0, arg1);
          return scope.Close(WrapXmlAttribute(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> TagNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->TagName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return;
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return;
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlElement^>(info.This()))
      {
        return;
      }

      XmlElement *wrapper = XmlElement::Unwrap<XmlElement>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlElement^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlElement(::Windows::Data::Xml::Dom::XmlElement^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlElement^ UnwrapXmlElement(Handle<Value> value);
    friend bool IsXmlElementWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlElement::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlElement(::Windows::Data::Xml::Dom::XmlElement^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlElement::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlElement^ UnwrapXmlElement(Handle<Value> value)
  {
     return XmlElement::Unwrap<XmlElement>(value.As<Object>())->_instance;
  }

  void InitXmlElement(Handle<Object> exports)
  {
    XmlElement::Init(exports);
  }

  class XmlDocumentFragment : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlDocumentFragment"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlDocumentFragment"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlDocumentFragment(::Windows::Data::Xml::Dom::XmlDocumentFragment^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlDocumentFragment^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlDocumentFragment^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlDocumentFragment *wrapperInstance = new XmlDocumentFragment(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return;
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return;
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlDocumentFragment^>(info.This()))
      {
        return;
      }

      XmlDocumentFragment *wrapper = XmlDocumentFragment::Unwrap<XmlDocumentFragment>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlDocumentFragment^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlDocumentFragment(::Windows::Data::Xml::Dom::XmlDocumentFragment^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlDocumentFragment^ UnwrapXmlDocumentFragment(Handle<Value> value);
    friend bool IsXmlDocumentFragmentWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlDocumentFragment::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlDocumentFragment(::Windows::Data::Xml::Dom::XmlDocumentFragment^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlDocumentFragment::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlDocumentFragment^ UnwrapXmlDocumentFragment(Handle<Value> value)
  {
     return XmlDocumentFragment::Unwrap<XmlDocumentFragment>(value.As<Object>())->_instance;
  }

  void InitXmlDocumentFragment(Handle<Object> exports)
  {
    XmlDocumentFragment::Init(exports);
  }

  class XmlText : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlText"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("splitText"), FunctionTemplate::New(SplitText)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("substringData"), FunctionTemplate::New(SubstringData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendData"), FunctionTemplate::New(AppendData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertData"), FunctionTemplate::New(InsertData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteData"), FunctionTemplate::New(DeleteData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceData"), FunctionTemplate::New(ReplaceData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("data"), DataGetter, DataSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlText"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlText(::Windows::Data::Xml::Dom::XmlText^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlText^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlText^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlText *wrapperInstance = new XmlText(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SplitText(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlText^ result;
          result = wrapper->_instance->SplitText(arg0);
          return scope.Close(WrapIXmlText(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SubstringData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          Platform::String^ result;
          result = wrapper->_instance->SubstringData(arg0, arg1);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->AppendData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->InsertData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> DeleteData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          wrapper->_instance->DeleteData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 3
        && args[0]->IsUint32()
        && args[1]->IsUint32()
        && args[2]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          wrapper->_instance->ReplaceData(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> DataGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Data;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return;
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Data = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return;
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return;
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlText^>(info.This()))
      {
        return;
      }

      XmlText *wrapper = XmlText::Unwrap<XmlText>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlText^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlText(::Windows::Data::Xml::Dom::XmlText^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlText^ UnwrapXmlText(Handle<Value> value);
    friend bool IsXmlTextWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlText::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlText(::Windows::Data::Xml::Dom::XmlText^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlText::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlText^ UnwrapXmlText(Handle<Value> value)
  {
     return XmlText::Unwrap<XmlText>(value.As<Object>())->_instance;
  }

  void InitXmlText(Handle<Object> exports)
  {
    XmlText::Init(exports);
  }

  class XmlComment : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlComment"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("substringData"), FunctionTemplate::New(SubstringData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendData"), FunctionTemplate::New(AppendData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertData"), FunctionTemplate::New(InsertData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteData"), FunctionTemplate::New(DeleteData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceData"), FunctionTemplate::New(ReplaceData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("data"), DataGetter, DataSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlComment"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlComment(::Windows::Data::Xml::Dom::XmlComment^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlComment^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlComment^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlComment *wrapperInstance = new XmlComment(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SubstringData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          Platform::String^ result;
          result = wrapper->_instance->SubstringData(arg0, arg1);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->AppendData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->InsertData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> DeleteData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          wrapper->_instance->DeleteData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 3
        && args[0]->IsUint32()
        && args[1]->IsUint32()
        && args[2]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          wrapper->_instance->ReplaceData(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> DataGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Data;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return;
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Data = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return;
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return;
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlComment^>(info.This()))
      {
        return;
      }

      XmlComment *wrapper = XmlComment::Unwrap<XmlComment>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlComment^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlComment(::Windows::Data::Xml::Dom::XmlComment^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlComment^ UnwrapXmlComment(Handle<Value> value);
    friend bool IsXmlCommentWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlComment::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlComment(::Windows::Data::Xml::Dom::XmlComment^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlComment::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlComment^ UnwrapXmlComment(Handle<Value> value)
  {
     return XmlComment::Unwrap<XmlComment>(value.As<Object>())->_instance;
  }

  void InitXmlComment(Handle<Object> exports)
  {
    XmlComment::Init(exports);
  }

  class XmlProcessingInstruction : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlProcessingInstruction"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("data"), DataGetter, DataSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("target"), TargetGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlProcessingInstruction"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlProcessingInstruction(::Windows::Data::Xml::Dom::XmlProcessingInstruction^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlProcessingInstruction^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlProcessingInstruction *wrapperInstance = new XmlProcessingInstruction(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> DataGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Data;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return;
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Data = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> TargetGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Target;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return;
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return;
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlProcessingInstruction^>(info.This()))
      {
        return;
      }

      XmlProcessingInstruction *wrapper = XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlProcessingInstruction(::Windows::Data::Xml::Dom::XmlProcessingInstruction^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ UnwrapXmlProcessingInstruction(Handle<Value> value);
    friend bool IsXmlProcessingInstructionWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlProcessingInstruction::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlProcessingInstruction(::Windows::Data::Xml::Dom::XmlProcessingInstruction^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlProcessingInstruction::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlProcessingInstruction^ UnwrapXmlProcessingInstruction(Handle<Value> value)
  {
     return XmlProcessingInstruction::Unwrap<XmlProcessingInstruction>(value.As<Object>())->_instance;
  }

  void InitXmlProcessingInstruction(Handle<Object> exports)
  {
    XmlProcessingInstruction::Init(exports);
  }

  class XmlEntityReference : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlEntityReference"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlEntityReference"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlEntityReference(::Windows::Data::Xml::Dom::XmlEntityReference^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlEntityReference^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlEntityReference^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlEntityReference *wrapperInstance = new XmlEntityReference(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return;
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return;
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlEntityReference^>(info.This()))
      {
        return;
      }

      XmlEntityReference *wrapper = XmlEntityReference::Unwrap<XmlEntityReference>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlEntityReference^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlEntityReference(::Windows::Data::Xml::Dom::XmlEntityReference^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlEntityReference^ UnwrapXmlEntityReference(Handle<Value> value);
    friend bool IsXmlEntityReferenceWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlEntityReference::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlEntityReference(::Windows::Data::Xml::Dom::XmlEntityReference^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlEntityReference::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlEntityReference^ UnwrapXmlEntityReference(Handle<Value> value)
  {
     return XmlEntityReference::Unwrap<XmlEntityReference>(value.As<Object>())->_instance;
  }

  void InitXmlEntityReference(Handle<Object> exports)
  {
    XmlEntityReference::Init(exports);
  }

  class XmlCDataSection : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlCDataSection"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("splitText"), FunctionTemplate::New(SplitText)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("substringData"), FunctionTemplate::New(SubstringData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendData"), FunctionTemplate::New(AppendData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertData"), FunctionTemplate::New(InsertData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("deleteData"), FunctionTemplate::New(DeleteData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceData"), FunctionTemplate::New(ReplaceData)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("data"), DataGetter, DataSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("length"), LengthGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlCDataSection"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlCDataSection(::Windows::Data::Xml::Dom::XmlCDataSection^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlCDataSection^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlCDataSection^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlCDataSection *wrapperInstance = new XmlCDataSection(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> SplitText(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && args[0]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          
          ::Windows::Data::Xml::Dom::IXmlText^ result;
          result = wrapper->_instance->SplitText(arg0);
          return scope.Close(WrapIXmlText(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SubstringData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          Platform::String^ result;
          result = wrapper->_instance->SubstringData(arg0, arg1);
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          wrapper->_instance->AppendData(arg0);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          Platform::String^ arg1 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[1])));
          
          wrapper->_instance->InsertData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> DeleteData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && args[0]->IsUint32()
        && args[1]->IsUint32())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          
          wrapper->_instance->DeleteData(arg0, arg1);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceData(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 3
        && args[0]->IsUint32()
        && args[1]->IsUint32()
        && args[2]->IsString())
      {
        try
        {
          unsigned int arg0 = static_cast<unsigned int>(args[0]->IntegerValue());
          unsigned int arg1 = static_cast<unsigned int>(args[1]->IntegerValue());
          Platform::String^ arg2 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[2])));
          
          wrapper->_instance->ReplaceData(arg0, arg1, arg2);
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> DataGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->Data;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void DataSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return;
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->Data = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> LengthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->Length;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return;
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return;
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlCDataSection^>(info.This()))
      {
        return;
      }

      XmlCDataSection *wrapper = XmlCDataSection::Unwrap<XmlCDataSection>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlCDataSection^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlCDataSection(::Windows::Data::Xml::Dom::XmlCDataSection^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlCDataSection^ UnwrapXmlCDataSection(Handle<Value> value);
    friend bool IsXmlCDataSectionWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlCDataSection::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlCDataSection(::Windows::Data::Xml::Dom::XmlCDataSection^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlCDataSection::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlCDataSection^ UnwrapXmlCDataSection(Handle<Value> value)
  {
     return XmlCDataSection::Unwrap<XmlCDataSection>(value.As<Object>())->_instance;
  }

  void InitXmlCDataSection(Handle<Object> exports)
  {
    XmlCDataSection::Init(exports);
  }

  class XmlLoadSettings : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("XmlLoadSettings"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
                              
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("validateOnParse"), ValidateOnParseGetter, ValidateOnParseSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("resolveExternals"), ResolveExternalsGetter, ResolveExternalsSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prohibitDtd"), ProhibitDtdGetter, ProhibitDtdSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("maxElementDepth"), MaxElementDepthGetter, MaxElementDepthSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("elementContentWhiteSpace"), ElementContentWhiteSpaceGetter, ElementContentWhiteSpaceSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("XmlLoadSettings"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    XmlLoadSettings(::Windows::Data::Xml::Dom::XmlLoadSettings^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::XmlLoadSettings^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::XmlLoadSettings^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else if (args.Length() == 0)
      {
        try
        {
          winRtInstance = ref new ::Windows::Data::Xml::Dom::XmlLoadSettings();
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      XmlLoadSettings *wrapperInstance = new XmlLoadSettings(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  



    static Handle<Value> ValidateOnParseGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        bool result = wrapper->_instance->ValidateOnParse;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ValidateOnParseSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsBoolean())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return;
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        
        bool winRtValue = value->BooleanValue();

        wrapper->_instance->ValidateOnParse = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ResolveExternalsGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        bool result = wrapper->_instance->ResolveExternals;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ResolveExternalsSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsBoolean())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return;
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        
        bool winRtValue = value->BooleanValue();

        wrapper->_instance->ResolveExternals = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ProhibitDtdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        bool result = wrapper->_instance->ProhibitDtd;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ProhibitDtdSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsBoolean())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return;
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        
        bool winRtValue = value->BooleanValue();

        wrapper->_instance->ProhibitDtd = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> MaxElementDepthGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        unsigned int result = wrapper->_instance->MaxElementDepth;
        return scope.Close(Integer::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void MaxElementDepthSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsUint32())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return;
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        
        unsigned int winRtValue = static_cast<unsigned int>(value->IntegerValue());

        wrapper->_instance->MaxElementDepth = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> ElementContentWhiteSpaceGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        bool result = wrapper->_instance->ElementContentWhiteSpace;
        return scope.Close(Boolean::New(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void ElementContentWhiteSpaceSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsBoolean())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::XmlLoadSettings^>(info.This()))
      {
        return;
      }

      XmlLoadSettings *wrapper = XmlLoadSettings::Unwrap<XmlLoadSettings>(info.This());

      try 
      {
        
        bool winRtValue = value->BooleanValue();

        wrapper->_instance->ElementContentWhiteSpace = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::XmlLoadSettings^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapXmlLoadSettings(::Windows::Data::Xml::Dom::XmlLoadSettings^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::XmlLoadSettings^ UnwrapXmlLoadSettings(Handle<Value> value);
    friend bool IsXmlLoadSettingsWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> XmlLoadSettings::s_constructorTemplate;

  v8::Handle<v8::Value> WrapXmlLoadSettings(::Windows::Data::Xml::Dom::XmlLoadSettings^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(XmlLoadSettings::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::XmlLoadSettings^ UnwrapXmlLoadSettings(Handle<Value> value)
  {
     return XmlLoadSettings::Unwrap<XmlLoadSettings>(value.As<Object>())->_instance;
  }

  void InitXmlLoadSettings(Handle<Object> exports)
  {
    XmlLoadSettings::Init(exports);
  }

  class DtdNotation : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("DtdNotation"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("publicId"), PublicIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("systemId"), SystemIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("DtdNotation"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    DtdNotation(::Windows::Data::Xml::Dom::DtdNotation^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::DtdNotation^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::DtdNotation^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      DtdNotation *wrapperInstance = new DtdNotation(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> PublicIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->PublicId;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SystemIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->SystemId;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return;
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return;
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdNotation^>(info.This()))
      {
        return;
      }

      DtdNotation *wrapper = DtdNotation::Unwrap<DtdNotation>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::DtdNotation^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapDtdNotation(::Windows::Data::Xml::Dom::DtdNotation^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::DtdNotation^ UnwrapDtdNotation(Handle<Value> value);
    friend bool IsDtdNotationWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> DtdNotation::s_constructorTemplate;

  v8::Handle<v8::Value> WrapDtdNotation(::Windows::Data::Xml::Dom::DtdNotation^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(DtdNotation::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::DtdNotation^ UnwrapDtdNotation(Handle<Value> value)
  {
     return DtdNotation::Unwrap<DtdNotation>(value.As<Object>())->_instance;
  }

  void InitDtdNotation(Handle<Object> exports)
  {
    DtdNotation::Init(exports);
  }

  class DtdEntity : public WrapperBase
  {
  public:    
    static v8::Handle<v8::Value> Init(const Handle<Object> exports)
    {
      HandleScope scope;
      
      s_constructorTemplate = Persistent<FunctionTemplate>::New(FunctionTemplate::New(New));
      s_constructorTemplate->SetClassName(String::NewSymbol("DtdEntity"));
      s_constructorTemplate->InstanceTemplate()->SetInternalFieldCount(1);
      
            
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("hasChildNodes"), FunctionTemplate::New(HasChildNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("insertBefore"), FunctionTemplate::New(InsertBefore)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("replaceChild"), FunctionTemplate::New(ReplaceChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("removeChild"), FunctionTemplate::New(RemoveChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("appendChild"), FunctionTemplate::New(AppendChild)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("cloneNode"), FunctionTemplate::New(CloneNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("normalize"), FunctionTemplate::New(Normalize)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNode"), FunctionTemplate::New(SelectSingleNode)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodes"), FunctionTemplate::New(SelectNodes)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectSingleNodeNS"), FunctionTemplate::New(SelectSingleNodeNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("selectNodesNS"), FunctionTemplate::New(SelectNodesNS)->GetFunction());
      s_constructorTemplate->PrototypeTemplate()->Set(String::NewSymbol("getXml"), FunctionTemplate::New(GetXml)->GetFunction());
      
                        
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("notationName"), NotationNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("publicId"), PublicIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("systemId"), SystemIdGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("prefix"), PrefixGetter, PrefixSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeValue"), NodeValueGetter, NodeValueSetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("firstChild"), FirstChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("lastChild"), LastChildGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("localName"), LocalNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("namespaceUri"), NamespaceUriGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nextSibling"), NextSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeName"), NodeNameGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("nodeType"), NodeTypeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("attributes"), AttributesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("ownerDocument"), OwnerDocumentGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("parentNode"), ParentNodeGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("childNodes"), ChildNodesGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("previousSibling"), PreviousSiblingGetter);
      s_constructorTemplate->PrototypeTemplate()->SetAccessor(String::NewSymbol("innerText"), InnerTextGetter, InnerTextSetter);
      
      Local<Function> constructor = s_constructorTemplate->GetFunction();


      exports->Set(String::NewSymbol("DtdEntity"), constructor);
      return scope.Close(Undefined());
    }


    virtual ::Platform::Object^ GetObjectInstance() const override
    {
      return _instance;
    }

  private:
    
    DtdEntity(::Windows::Data::Xml::Dom::DtdEntity^ instance)
    {
      _instance = instance;
    }
    
    
    static v8::Handle<v8::Value> New(const v8::Arguments& args)
    {
      HandleScope scope;

      // in case the constructor was called without the new operator
      if (!s_constructorTemplate->HasInstance(args.This()))
      {
        if (args.Length() > 0)
        {
          std::unique_ptr<Handle<Value> []> constructorArgs(new Handle<Value>[args.Length()]);

          Handle<Value> *argsPtr = constructorArgs.get();
          for (int i = 0; i < args.Length(); i++)
          {
            argsPtr[i] = args[i];
          }

          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), constructorArgs.get());
        }
        else
        {
          return s_constructorTemplate->GetFunction()->CallAsConstructor(args.Length(), nullptr);
        }
      }
      
      ::Windows::Data::Xml::Dom::DtdEntity^ winRtInstance;


      if (args.Length() == 1 && OpaqueWrapper::IsOpaqueWrapper(args[0]) &&
        NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args[0]))
      {
        try 
        {
          winRtInstance = (::Windows::Data::Xml::Dom::DtdEntity^) NodeRT::Utils::GetObjectInstance(args[0]);
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Invalid arguments, no suitable constructor found")));
        return scope.Close(Undefined());
      }

      args.This()->SetHiddenValue(String::NewSymbol("__winRtInstance__"), True());

      DtdEntity *wrapperInstance = new DtdEntity(winRtInstance);
      wrapperInstance->Wrap(args.This());

      return args.This();
    }


  
    static Handle<Value> HasChildNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          bool result;
          result = wrapper->_instance->HasChildNodes();
          return scope.Close(Boolean::New(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> InsertBefore(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->InsertBefore(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> ReplaceChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 2
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0])
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[1]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          ::Windows::Data::Xml::Dom::IXmlNode^ arg1 = UnwrapIXmlNode(args[1]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->ReplaceChild(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> RemoveChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->RemoveChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> AppendChild(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 1
        && NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::IXmlNode^>(args[0]))
      {
        try
        {
          ::Windows::Data::Xml::Dom::IXmlNode^ arg0 = UnwrapIXmlNode(args[0]);
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->AppendChild(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> CloneNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 1
        && args[0]->IsBoolean())
      {
        try
        {
          bool arg0 = args[0]->BooleanValue();
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->CloneNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> Normalize(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          wrapper->_instance->Normalize();
          return scope.Close(Undefined());   
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNode(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNode(arg0);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodes(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 1
        && args[0]->IsString())
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodes(arg0);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectSingleNodeNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::IXmlNode^ result;
          result = wrapper->_instance->SelectSingleNodeNS(arg0, arg1);
          return scope.Close(WrapIXmlNode(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> SelectNodesNS(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 2
        && args[0]->IsString()
        && NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(args[1]))
      {
        try
        {
          Platform::String^ arg0 = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(args[0])));
          ::Platform::Object^ arg1 = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(args[1]));
          
          ::Windows::Data::Xml::Dom::XmlNodeList^ result;
          result = wrapper->_instance->SelectNodesNS(arg0, arg1);
          return scope.Close(WrapXmlNodeList(result));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }
    static Handle<Value> GetXml(const v8::Arguments& args)
    {
      HandleScope scope;

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(args.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(args.This());

      if (args.Length() == 0)
      {
        try
        {
          Platform::String^ result;
          result = wrapper->_instance->GetXml();
          return scope.Close(NodeRT::Utils::NewString(result->Data()));
        }
        catch (Platform::Exception ^exception)
        {
          NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
          return scope.Close(Undefined());
        }
      }
      else 
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Bad arguments: no suitable overload found")));
        return scope.Close(Undefined());
      }

      return scope.Close(Undefined());
    }



    static Handle<Value> NotationNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NotationName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PublicIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->PublicId;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> SystemIdGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->SystemId;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PrefixGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->Prefix;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void PrefixSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return;
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->Prefix = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> NodeValueGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NodeValue;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void NodeValueSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Platform::Object^>(value))
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return;
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        
        ::Platform::Object^ winRtValue = dynamic_cast<::Platform::Object^>(NodeRT::Utils::GetObjectInstance(value));

        wrapper->_instance->NodeValue = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    
    static Handle<Value> FirstChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->FirstChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LastChildGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->LastChild;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> LocalNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->LocalName;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NamespaceUriGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Platform::Object^ result = wrapper->_instance->NamespaceUri;
        return scope.Close(CreateOpaqueWrapper(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NextSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->NextSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeNameGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->NodeName;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> NodeTypeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::NodeType result = wrapper->_instance->NodeType;
        return scope.Close(Integer::New(static_cast<int>(result)));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> AttributesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNamedNodeMap^ result = wrapper->_instance->Attributes;
        return scope.Close(WrapXmlNamedNodeMap(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> OwnerDocumentGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlDocument^ result = wrapper->_instance->OwnerDocument;
        return scope.Close(WrapXmlDocument(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ParentNodeGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->ParentNode;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> ChildNodesGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::XmlNodeList^ result = wrapper->_instance->ChildNodes;
        return scope.Close(WrapXmlNodeList(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> PreviousSiblingGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        ::Windows::Data::Xml::Dom::IXmlNode^ result = wrapper->_instance->PreviousSibling;
        return scope.Close(WrapIXmlNode(result));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static Handle<Value> InnerTextGetter(Local<String> property, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return scope.Close(Undefined());
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        Platform::String^ result = wrapper->_instance->InnerText;
        return scope.Close(NodeRT::Utils::NewString(result->Data()));
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
        return scope.Close(Undefined());
      }
    }
    
    static void InnerTextSetter(Local<String> property, Local<Value> value, const AccessorInfo &info)
    {
      HandleScope scope;
      
      if (!value->IsString())
      {
        ThrowException(Exception::Error(NodeRT::Utils::NewString(L"Value to set is of unexpected type")));
        return;
      }

      if (!NodeRT::Utils::IsWinRtWrapperOf<::Windows::Data::Xml::Dom::DtdEntity^>(info.This()))
      {
        return;
      }

      DtdEntity *wrapper = DtdEntity::Unwrap<DtdEntity>(info.This());

      try 
      {
        
        Platform::String^ winRtValue = ref new Platform::String(NodeRT::Utils::StringToWchar(v8::String::Value(value)));

        wrapper->_instance->InnerText = winRtValue;
      }
      catch (Platform::Exception ^exception)
      {
        NodeRT::Utils::ThrowWinRtExceptionInJs(exception);
      }
    }
    


  private:
    ::Windows::Data::Xml::Dom::DtdEntity^ _instance;
    static Persistent<FunctionTemplate> s_constructorTemplate;

    friend v8::Handle<v8::Value> WrapDtdEntity(::Windows::Data::Xml::Dom::DtdEntity^ wintRtInstance);
    friend ::Windows::Data::Xml::Dom::DtdEntity^ UnwrapDtdEntity(Handle<Value> value);
    friend bool IsDtdEntityWrapper(Handle<Value> value);
  };
  Persistent<FunctionTemplate> DtdEntity::s_constructorTemplate;

  v8::Handle<v8::Value> WrapDtdEntity(::Windows::Data::Xml::Dom::DtdEntity^ winRtInstance)
  {
    HandleScope scope;

    if (winRtInstance == nullptr)
    {
      return scope.Close(Undefined());
    }

    Handle<Object> opaqueWrapper = CreateOpaqueWrapper(winRtInstance);
    Handle<Value> args[] = {opaqueWrapper};
    return scope.Close(DtdEntity::s_constructorTemplate->GetFunction()->NewInstance(_countof(args), args));
  }

  ::Windows::Data::Xml::Dom::DtdEntity^ UnwrapDtdEntity(Handle<Value> value)
  {
     return DtdEntity::Unwrap<DtdEntity>(value.As<Object>())->_instance;
  }

  void InitDtdEntity(Handle<Object> exports)
  {
    DtdEntity::Init(exports);
  }

} } } } } 

void init(Handle<Object> exports)
{
  if (FAILED(CoInitializeEx(nullptr, COINIT_MULTITHREADED)))
  {
    ThrowException(v8::Exception::Error(NodeRT::Utils::NewString(L"error in CoInitializeEx()")));
    return;
  }
  
  NodeRT::Windows::Data::Xml::Dom::InitNodeTypeEnum(exports);
  NodeRT::Windows::Data::Xml::Dom::InitIXmlNodeSelector(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlNodeList(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlNamedNodeMap(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlDocument(exports);
  NodeRT::Windows::Data::Xml::Dom::InitIXmlNodeSerializer(exports);
  NodeRT::Windows::Data::Xml::Dom::InitIXmlNode(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlAttribute(exports);
  NodeRT::Windows::Data::Xml::Dom::InitIXmlCharacterData(exports);
  NodeRT::Windows::Data::Xml::Dom::InitIXmlText(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlDocumentType(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlDomImplementation(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlElement(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlDocumentFragment(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlText(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlComment(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlProcessingInstruction(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlEntityReference(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlCDataSection(exports);
  NodeRT::Windows::Data::Xml::Dom::InitXmlLoadSettings(exports);
  NodeRT::Windows::Data::Xml::Dom::InitDtdNotation(exports);
  NodeRT::Windows::Data::Xml::Dom::InitDtdEntity(exports);

  NodeRT::Utils::RegisterNameSpace("Windows.Data.Xml.Dom", exports);
}


NODE_MODULE(binding, init)